@@ -48,7 +48,6 @@ grant insert,select on table instance to smith;
 grant insert on table error to smith;
 grant update,insert,select on table stat to smith;
 grant usage on all sequences in schema public to smith;
-grant select on boring_sqlstates to smith;
 
 -- stuff beyond this line is not referenced by sqlsmith
 
@@ -89,6 +88,16 @@ create view report24h as
        where i.t > now() - interval '1 days'
        	     group by 2 order by count desc;
 
+create or replace view reporthosts as
+ SELECT count(1) AS count,
+    substring(firstline(e.msg),1,80) as firstline,
+    array_agg(DISTINCT i.hostname) AS hosts
+   FROM error e
+     JOIN instance i ON i.id = e.id
+  WHERE e.t > (now() - '24:00:00'::interval)
+  GROUP BY 2
+  ORDER BY (count(1));
+
 create view instance_activity as
        select i.hostname, i.target, max(e.t)
        	      from instance i join error e on (i.id = e.id)
@@ -109,12 +118,16 @@ comment on view instance_speed is 'query speed of recently active instances';
 
 create table boring_sqlstates (sqlstate text primary key);
 comment on table boring_sqlstates is 'sqlstates to reject';
+grant select on boring_sqlstates to public;
+\copy boring_sqlstates from boring_sqlstates.txt
 
 create table known(error text);
 comment on table known is 'error messages to reject';
+\copy known from known.txt
 
 create table known_re(re text);
 comment on table known_re is 'regular expressions to match error messages to reject';
+\copy known_re from known_re.txt
 
 create or replace function discard_known() returns trigger as $$
 begin
